@@ -1,7 +1,7 @@
 #![warn(clippy::all)]
 
 use crate::imdb::title_type::TitleType;
-use crate::Res;
+use crate::utils::result::Res;
 use derive_more::Display;
 use std::error::Error;
 
