@@ -1,4 +1,7 @@
 #![warn(clippy::all)]
+#![warn(missing_docs)]
+
+//! Module for TVrank to use the IMDB dataset (TSV dumps) as a source.
 
 mod db;
 mod error;
@@ -9,7 +12,7 @@ mod title;
 mod title_header;
 mod title_id;
 mod title_type;
-mod utils;
+mod tokens;
 
 pub use db::Query as ImdbQuery;
 pub use error::Err as ImdbErr;
